==> kvalifika_sdk-0.3.0.tar.gz: android/src/main/kotlin/com/kvalifika/kvalifika_sdk/KvalifikaSdkPlugin.kt <==
package com.kvalifika.kvalifika_sdk

import android.app.Activity
import androidx.annotation.NonNull
import com.kvalifika.sdk.KvalifikaSDK
import com.kvalifika.sdk.KvalifikaSDKCallback
import com.kvalifika.sdk.KvalifikaSDKError
import com.kvalifika.sdk.KvalifikaSDKLocale
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


/** KvalifikaSdkPlugin */
class KvalifikaSdkPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var activity: Activity
  private lateinit var sdk: KvalifikaSDK
  private var initialized = false

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "kvalifika_sdk")
    channel.setMethodCallHandler(this)
  }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        this.activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onDetachedFromActivity() {
    }

    private fun getLocale(locale: String): KvalifikaSDKLocale {
        return when (locale) {
            "EN" -> {
                KvalifikaSDKLocale.EN
            }
            "GE" -> {
                KvalifikaSDKLocale.GE
            }
            else -> {
                KvalifikaSDKLocale.EN
            }
        }
    }

    private fun getCustomizationResource(@NonNull call: MethodCall, name: String): Int {
        val arg = call.argument<String>(name)
        if(arg == null || arg == "") return 0
        return activity.applicationContext.resources.getIdentifier(arg, "drawable", activity.applicationContext.packageName)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "getPlatformVersion" -> {
                result.success("Android ${android.os.Build.VERSION.RELEASE}")
            }
            "sdkInitialize" -> {
                if(initialized) return

                val appId = call.argument<String>("appId")
                val locale = call.argument<String>("locale")

                if (appId == null || locale == null) return

                val logo = getCustomizationResource(call, "logo")
                val documentIcon = getCustomizationResource(call, "documentIcon")
                val cancelIcon = getCustomizationResource(call, "cancelIcon")
                val activeFlashIcon = getCustomizationResource(call, "activeFlashIcon")
                val inactiveFlashIcon = getCustomizationResource(call, "inactiveFlashIcon")

                sdk = KvalifikaSDK.Builder(activity, appId)
                        .logo(logo)
                        .documentIcon(documentIcon)
                        .cancelIcon(cancelIcon)
                        .activeFlashIcon(activeFlashIcon)
                        .inactiveFlashIcon(inactiveFlashIcon)
                        .locale(getLocale(locale))
                        .build()

                sdk.callback(object : KvalifikaSDKCallback {
                    override fun onInitialize() {
                        activity.runOnUiThread {
                            channel.invokeMethod("sdkOnInitialize", "")
                        }
                    }

                    override fun onStart(sessionId: String) {
                        activity.runOnUiThread {
                            channel.invokeMethod("sdkOnStart", sessionId)
                        }
                    }

                    override fun onFinish(sessionId: String) {
                        activity.runOnUiThread {
                            channel.invokeMethod("sdkOnFinish", sessionId)
                        }
                    }

                    override fun onError(error: KvalifikaSDKError, message: String?) {
                        activity.runOnUiThread {
                            var msg = "";
                            if(message != null) {
                                msg = message;
                            }

                            channel.invokeMethod("sdkOnError", "${error.name}___${msg}");
                        }
                    }
                })

                initialized = true
                result.success(true)
            }
            "sdkStartSession" -> {
                sdk.startSession()
            }
        else -> {
          result.notImplemented()
        }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}

==> kvalifika_sdk-0.10.0.tar.gz: android/src/main/kotlin/com/kvalifika/kvalifika_sdk/KvalifikaSdkPlugin.kt <==
package com.kvalifika.kvalifika_sdk

import android.app.Activity
import androidx.annotation.NonNull
import com.kvalifika.sdk.KvalifikaSDK
import com.kvalifika.sdk.KvalifikaSDKCallback
import com.kvalifika.sdk.KvalifikaSDKError
import com.kvalifika.sdk.KvalifikaSDKLocale
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


/** KvalifikaSdkPlugin */
class KvalifikaSdkPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var activity: Activity
  private lateinit var sdk: KvalifikaSDK
  private var initialized = false

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "kvalifika_sdk")
    channel.setMethodCallHandler(this)
  }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        this.activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onDetachedFromActivity() {
    }

    private fun getLocale(locale: String): KvalifikaSDKLocale {
        return when (locale) {
            "EN" -> {
                KvalifikaSDKLocale.EN
            }
            "GE" -> {
                KvalifikaSDKLocale.GE
            }
            else -> {
                KvalifikaSDKLocale.EN
            }
        }
    }

    private fun getCustomizationResource(@NonNull call: MethodCall, name: String): Int {
        val arg = call.argument<String>(name)
        if(arg == null || arg == "") return 0
        return activity.applicationContext.resources.getIdentifier(arg, "drawable", activity.applicationContext.packageName)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "getPlatformVersion" -> {
                result.success("Android ${android.os.Build.VERSION.RELEASE}")
            }
            "sdkInitialize" -> {
                if(initialized) return

                val appId = call.argument<String>("appId")
                val locale = call.argument<String>("locale")
                val development = call.argument<Boolean>("development")

                if (appId == null || locale == null || development == null) return

                val logo = getCustomizationResource(call, "logo")
                val documentIcon = getCustomizationResource(call, "documentIcon")
                val cancelIcon = getCustomizationResource(call, "cancelIcon")
                val activeFlashIcon = getCustomizationResource(call, "activeFlashIcon")
                val inactiveFlashIcon = getCustomizationResource(call, "inactiveFlashIcon")

                sdk = KvalifikaSDK.Builder(activity, appId)
                        .logo(logo)
                        .documentIcon(documentIcon)
                        .cancelIcon(cancelIcon)
                        .activeFlashIcon(activeFlashIcon)
                        .inactiveFlashIcon(inactiveFlashIcon)
                        .locale(getLocale(locale))
                        .development(development)
                        .build()

                sdk.callback(object : KvalifikaSDKCallback {
                    override fun onInitialize() {
                        activity.runOnUiThread {
                            channel.invokeMethod("sdkOnInitialize", "")
                        }
                    }

                    override fun onStart(sessionId: String) {
                        activity.runOnUiThread {
                            channel.invokeMethod("sdkOnStart", sessionId)
                        }
                    }

                    override fun onFinish(sessionId: String) {
                        activity.runOnUiThread {
                            channel.invokeMethod("sdkOnFinish", sessionId)
                        }
                    }

                    override fun onError(error: KvalifikaSDKError, message: String?) {
                        activity.runOnUiThread {
                            var msg = "";
                            if(message != null) {
                                msg = message;
                            }

                            channel.invokeMethod("sdkOnError", "${error.name}___${msg}");
                        }
                    }
                })

                initialized = true
                result.success(true)
            }
            "sdkStartSession" -> {
                sdk.startSession()
                result.success(true)
            }
        else -> {
          result.notImplemented()
        }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
